# Generated by roxygen2: do not edit by hand

export(CellWindX_DimPlot)
export(CellWindX_GeneRadar)
export(CellWindX_MarkerHeatmap)
export(CellWindX_TopMarkersStats)
importFrom(stats,ave)
importFrom(stats,median)
importFrom(stats,setNames)
importFrom(utils,write.csv)
